@@ -1,5 +1,7 @@
 import re
+from collections import namedtuple
 from fnmatch import fnmatchcase
+from . import settings as smart_settings
 
 from django.core.exceptions import ObjectDoesNotExist
 
@@ -71,3 +73,30 @@ def get_related(user, field):
         info["related_name"] = field.related_model._meta.verbose_name
 
     return info
+
+#
+# Link = namedtuple('Link', "label,href,css_class")
+# Sep = namedtuple('Sep', "css_class")
+
+def get_bookmarks2(request):
+    return smart_settings.get_bookmarks(request)
+    # if smart_settings.BOOKMARKS_PERMISSION is None or request.user.has_permission(
+    #         smart_settings.BOOKMARKS_PERMISSION):
+    #     bookmarks = []
+    #     values = smart_settings.get_bookmarks(request)
+    #     for defs in values:
+    #         if not defs:
+    #             continue
+    #         if isinstance(defs, (Link, Sep)):
+    #             entry = defs
+    #         elif isinstance(defs, str):
+    #             entry = defs
+    #         elif isinstance(defs, (list, tuple)) and len(defs) == 2:
+    #             entry = Link(defs[0], defs[1], 'viewlink')
+    #         elif isinstance(defs, (list, tuple)) and len(defs) == 3:
+    #             entry = Link(defs)
+    #         else:
+    #             raise ValueError(f"Invalid QuickLink definition '{defs}' for BOOKMARKS")
+    #         bookmarks.append(entry)
+    #     return bookmarks
+    # return []
